#include <Adafruit_Fingerprint.h> // v2.1.0

SoftwareSerial seriIletisim(2, 3); // Arduino'da 2. pini Rx, 3. pini TX olarak kullan.

Adafruit_Fingerprint parmakIzi = Adafruit_Fingerprint(&seriIletisim);

void setup() {
  Serial.begin(9600);
  Serial.println("\n\nParmak izi okuma.");
  parmakIzi.begin(57600); // Sensör seri portu.

  if (parmakIzi.verifyPassword()) {
    Serial.println("Parmak izi sensörü tespit edildi.");
  } else {
    Serial.println("Parmak izi sensörü tespit edilemedi :(");
    while (1) {
      delay(1);
    }
  }

  parmakIzi.getTemplateCount();
  Serial.print("Hafizada "); Serial.print(parmakIzi.templateCount); Serial.println(" parmak izi mevcut.");
  Serial.println("Lütfen parmağınızı okuyucuya yerleştiriniz.");
  Serial.println("Parmak izi tespit ediliyor...");
}

void loop() {
  getFingerprintIDez();
  delay(50);
}

byte getFingerprintID() {
  byte p = parmakIzi.getImage();
  switch (p) {
    case FINGERPRINT_OK:
      Serial.println("Görüntü kaydedildi.");
      break;
    case FINGERPRINT_NOFINGER:
      Serial.println("Parmak izi yok");
      return p;
    case FINGERPRINT_PACKETRECIEVEERR:
      Serial.println("İletişim hatası.");
      return p;
    case FINGERPRINT_IMAGEFAIL:
      Serial.println("Görüntüleme hatası.");
      return p;
    default:
      Serial.println("Bilinmeyen hata.");
      return p;
  }

  p = parmakIzi.image2Tz();
  switch (p) {
    case FINGERPRINT_OK:
      Serial.println("Görüntü işlendi.");
      break;
    case FINGERPRINT_IMAGEMESS:
      Serial.println("Görüntü karışık.");
      return p;
    case FINGERPRINT_PACKETRECIEVEERR:
      Serial.println("İletişim hatası.");
      return p;
    case FINGERPRINT_FEATUREFAIL:
      Serial.println("Parmak izi özellikleri bulunamadı.");
      return p;
    case FINGERPRINT_INVALIDIMAGE:
      Serial.println("Parmak izi özellikleri bulunamadı.");
      return p;
    default:
      Serial.println("Bilinmeyen hata.");
      return p;
  }

  p = parmakIzi.fingerFastSearch();
  if (p == FINGERPRINT_OK) {
    Serial.println("Bir parmak izi ile eşleşti!");
  } else if (p == FINGERPRINT_PACKETRECIEVEERR) {
    Serial.println("İletişim hatası.");
    return p;
  } else if (p == FINGERPRINT_NOTFOUND) {
    Serial.println("Eşleşme bulunamadı.");
    return p;
  } else {
    Serial.println("Bilinmeyen hata.");
    return p;
  }

  Serial.print("Bulunan ID: "); Serial.print(parmakIzi.fingerID);
  Serial.print(" doğruluk seviyesi: "); Serial.println(parmakIzi.confidence);

  return parmakIzi.fingerID;
}

int getFingerprintIDez() {
  byte p = parmakIzi.getImage();
  if (p != FINGERPRINT_OK) return -1;

  p = parmakIzi.image2Tz();
  if (p != FINGERPRINT_OK) return -1;

  p = parmakIzi.fingerFastSearch();
  if (p != FINGERPRINT_OK) return -1;

  Serial.print("Bulunan ID: "); Serial.print(parmakIzi.fingerID);
  Serial.print(" doğruluk seviyesi: "); Serial.println(parmakIzi.confidence);
  return parmakIzi.fingerID;
}
